==> gatsby-theme-jason-blog-1.4.1.tgz: package/src/components/PostMeta.js <==
import React from 'react';
import PropTypes from 'prop-types';
import styled from '@emotion/styled';
import Img from 'gatsby-image';
import { Link } from 'gatsby';
import CategoryLink from './CategoryLink';
import TagLink from './TagLink';
import { colors, media } from '../tokens';

const Wrapper = styled('aside')`
  color: ${colors.gray};
  display: none;
  font-size: 0.625rem;
  text-align: center;

  @media ${media.large} {
    display: block;
  }
`;

const StickyContainer = styled('div')`
  @media ${media.large} {
    @supports (position: sticky) {
      position: sticky;
      top: 5rem;
    }
  }
`;

const Image = styled(Img)`
  display: block;
  border: 1px solid ${colors.grayAlpha};
`;

const Text = styled('p')`
  margin-top: 0.75rem;
`;

const PostMeta = ({
  thumb,
  categories,
  tags,
  className,
  linkRoot = 'blog',
}) => (
  <Wrapper className={className}>
    <StickyContainer>
      <Image
        style={{ display: 'inherit' }}
        alt="Jason Lengstorf."
        fluid={thumb.fluid}
      />
      <Text>Posted in:</Text>
      {categories.map(category => (
        <CategoryLink
          key={`category-${category}`}
          category={category}
          linkRoot={linkRoot}
          block
        />
      ))}
      <Text>Tags:</Text>
      {tags.map(tag => (
        <TagLink key={`tag-${tag}`} linkRoot={linkRoot} tag={tag} />
      ))}
      <Text>
        If you want to get more posts like this,{' '}
        <Link to="/newsletter/">join my newsletter</Link>.
      </Text>
    </StickyContainer>
  </Wrapper>
);

PostMeta.propTypes = {
  className: PropTypes.string.isRequired,
  categories: PropTypes.arrayOf(PropTypes.string).isRequired,
  tags: PropTypes.arrayOf(PropTypes.string).isRequired,
  thumb: PropTypes.shape({
    fluid: PropTypes.any,
  }).isRequired,
};

export default PostMeta;

==> gatsby-theme-jason-blog-2.0.2.tgz: package/src/components/PostMeta.js <==
import React from 'react';
import PropTypes from 'prop-types';
import styled from '@emotion/styled';
import Img from 'gatsby-image';
import { Link } from 'gatsby';
import CategoryLink from './CategoryLink';
import TagLink from './TagLink';
import { colors, media } from '../tokens';

const Wrapper = styled('aside')`
  color: ${colors.gray};
  display: none;
  font-size: 0.625rem;
  text-align: center;

  @media ${media.large} {
    display: block;
  }
`;

const StickyContainer = styled('div')`
  @media ${media.large} {
    @supports (position: sticky) {
      position: sticky;
      top: 5rem;
    }
  }
`;

const Image = styled(Img)`
  display: block;
  border: 1px solid ${colors.grayAlpha};
`;

const Text = styled('p')`
  margin-top: 0.75rem;
`;

const PostMeta = ({
  thumb,
  categories,
  tags,
  className,
  linkRoot = 'blog',
}) => (
  <Wrapper className={className}>
    <StickyContainer>
      <Image
        style={{ display: 'inherit' }}
        alt="Jason Lengstorf."
        fluid={thumb.fluid}
      />
      <Text>Posted in:</Text>
      {categories.map((category) => (
        <CategoryLink
          key={`category-${category}`}
          category={category}
          linkRoot={linkRoot}
          block
        />
      ))}
      <Text>Tags:</Text>
      {tags.map((tag) => (
        <TagLink key={`tag-${tag}`} linkRoot={linkRoot} tag={tag} />
      ))}
      <Text>
        If you want to get more posts like this,{' '}
        <Link to="/newsletter/">join my newsletter</Link>.
      </Text>
    </StickyContainer>
  </Wrapper>
);

PostMeta.propTypes = {
  className: PropTypes.string.isRequired,
  categories: PropTypes.arrayOf(PropTypes.string).isRequired,
  tags: PropTypes.arrayOf(PropTypes.string).isRequired,
  thumb: PropTypes.shape({
    fluid: PropTypes.any,
  }).isRequired,
};

export default PostMeta;
